@@ -9,7 +9,7 @@ Copyright 2011 Mozes, Inc.
 
    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
-   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either expressed or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
 """
@@ -18,19 +18,25 @@ import unittest
 from stompest.simple import Stomp
 
 class SimpleStompIntegrationTest(unittest.TestCase):
+    DEST = '/queue/stompUnitTest'
     
-    def test_integration(self):
-        dest = '/queue/stompUnitTest'
+    def setUp(self):
         stomp = Stomp('localhost', 61613)
         stomp.connect()
-        stomp.send(dest, 'test message1')
-        stomp.send(dest, 'test message2')
+        stomp.subscribe(self.DEST, {'ack': 'client'})
+        while (stomp.canRead(1)):
+            stomp.ack(stomp.receiveFrame())
+        
+    def test_integration(self):
+        stomp = Stomp('localhost', 61613)
+        stomp.connect()
+        stomp.send(self.DEST, 'test message1')
+        stomp.send(self.DEST, 'test message2')
         self.assertFalse(stomp.canRead(1))
-        stomp.subscribe(dest, {'ack': 'client'})
+        stomp.subscribe(self.DEST, {'ack': 'client'})
         self.assertTrue(stomp.canRead(1))
         frame = stomp.receiveFrame()
         stomp.ack(frame)
-        stomp.canRead(1)
         self.assertTrue(stomp.canRead(1))
         frame = stomp.receiveFrame()
         stomp.ack(frame)
